@@ -1,6 +1,3 @@
-import os
-import sys
-from sparrow.file_ops import ppath
 
 
 def calc_number_digit(number):
